The `dnsinfo.h` header was extracted from Apple's OpenSource repository:
[https://opensource.apple.com/source/configd/configd-1109.140.1/dnsinfo/dnsinfo.h](https://opensource.apple.com/source/configd/configd-1109.140.1/dnsinfo/dnsinfo.h)

This is needed to call into `dns_configuration_copy()` and `dns_configuration_free()`.
